#
# spec file for package alsa-firmware
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           alsa-firmware
%define package_version	1.0.27
Url:            http://www.alsa-project.org/
Summary:        Firmware Data Files for ALSA
License:        GPL-2.0+
Group:          Hardware/Other
BuildRequires:  automake
%if 0%{?suse_version} > 1220
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(udev)
%endif
Version:        1.0.27
Release:        2.1
Source:         ftp://ftp.alsa-project.org/pub/firmware/alsa-firmware-%{package_version}.tar.bz2
Source1:        usx2yaudio.rules
Source2:        usx2yaudio-old.rules
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
Requires:       alsa
%if 0%{?suse_version} > 1220
%define _udevdir %(pkg-config --variable=udevdir udev)
%else
%define _udevdir /etc/udev
%endif

%description
Various firmware data files for ALSA drivers.

%prep
%setup -q -n %{name}-%{package_version}

%build
autoreconf -fi
%configure \
    --enable-loader \
    --enable-hotplug \
    --with-hotplug-dir=/lib/firmware
make %{?_smp_mflags}

%install
make DESTDIR="$RPM_BUILD_ROOT" install
# remove unnecessary loader firmwares
for d in vxloader mixartloader pcxhrloader; do
  rm -rf $RPM_BUILD_ROOT%{_datadir}/alsa/firmware/$d
done
%if 0%{?suse_version} >= 1120
# some files are included in the new "kernel-firmware" package
for d in ess korg sb16 yamaha; do
  rm -rf $RPM_BUILD_ROOT/lib/firmware/$d
done
%endif
# change identical files to symlinks for hdsploader
pushd $RPM_BUILD_ROOT%{_datadir}/alsa/firmware/hdsploader
for i in *.bin; do
  hotplug=$RPM_BUILD_ROOT/lib/firmware/$i
  if [ -f $hotplug ]; then
    if cmp -s -b $hotplug $i; then
      rm $i
      ln -s /lib/firmware/$i
    fi
  fi
done
popd
# FIXME: remove non-existing msnd firmware symlinks
rm -rf $RPM_BUILD_ROOT/lib/firmware/turtlebeach
# install documents
mkdir -p $RPM_BUILD_ROOT%{_docdir}/%{name}
for d in echoaudio hdsploader mixartloader pcxhrloader usx2yloader vxloader asihpi ca0132; do
  (cd $d
  n=${d##*/}
  mkdir -p $RPM_BUILD_ROOT%{_docdir}/%{name}/$n
  for f in AUTHORS COPYING ChangeLog NEWS README* TODO creative.txt; do
    test -f $f || continue
    install -c -m 0644 $f $RPM_BUILD_ROOT%{_docdir}/%{name}/$n
  done
  )
done
# udev rules
%if 0%{?suse_version} > 1020
install -D -c -m 0644 %{SOURCE1} $RPM_BUILD_ROOT%{_udevdir}/rules.d/52-usx2yaudio.rules
%else
install -D -c -m 0644 %{SOURCE2} $RPM_BUILD_ROOT%{_udevdir}/rules.d/52-usx2yaudio.rules
%endif

%files
%defattr(-, root, root)
%doc %{_docdir}/%{name}
/lib/firmware/*
%{_datadir}/alsa
%{_udevdir}

%changelog
* Fri Apr 12 2013 tiwai@suse.de
- Updated to version 1.0.27:
  add firmware files for CA0132 HD-audio codec
- Fix macros for udev rules installation path
* Wed Jan 25 2012 tiwai@suse.de
- updated to version 1.0.25; Update asihpi firmware to 4.10.05
* Thu Dec 22 2011 crrodriguez@opensuse.org
- alsa firmware is of no use without alsa
* Fri Dec  2 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
- Use %%_smp_mflags for parallel build
* Mon Jan 31 2011 tiwai@suse.de
- Updated to version 1.0.24.1:
  * including previous fixes
  * Add firmware for HDSP RPM
* Mon Apr 19 2010 tiwai@suse.de
- updated to version 1.0.23:
  * update asihpi firmware version 40304
* Wed Feb 24 2010 aj@suse.de
- Use ATTR instead of SYSFS for udev rules.
* Mon Oct  5 2009 tiwai@suse.de
- really exclude firmware files in kernel-firmware package
* Wed May  6 2009 tiwai@suse.de
- updated to version 1.0.20:
  * just a version number bump
* Tue May  5 2009 tiwai@suse.de
- exclude some firmware files already contained in kernel-firmware
  package
* Thu Mar  5 2009 ro@suse.de
- fix build
* Thu Jan 22 2009 tiwai@suse.de
- updated to version 1.0.19:
  * updated PCXHR firmwares
* Tue Jul 15 2008 tiwai@suse.de
- updated to version 1.0.17:
  * just a version bump
* Thu Jun 26 2008 tiwai@suse.de
- updated to version 1.0.17-rc2:
  * update asihpi firmwares
* Fri Feb  8 2008 tiwai@suse.de
- updated to version 1.0.16-final:
  * just a version bump
* Mon Jan 28 2008 tiwai@suse.de
- changed the package version number to 1.0.16 to match with
  alsa-tools.
* Tue Jan 22 2008 tiwai@suse.de
- updated to version 1.0.16rc1:
  * updated asihpi firmware data
* Tue Oct 16 2007 tiwai@suse.de
- updated to version 1.0.15-final:
  * including all previous fixes
* Mon Jul 30 2007 tiwai@suse.de
- updated to firmware version (as of HG 2007.07.27)
  including the latest ASIHPI binaries
- fixed udev rules for the recent 10.3 kernel.
  keep the old config for older kernels.
* Tue Jun  5 2007 tiwai@suse.de
- removed alsa from BuildRequires
- fixed filelist to be independent from alsa.rpm
* Thu May 31 2007 tiwai@suse.de
- updated to version 1.0.14-final:
  * aica firmware
* Wed May  2 2007 tiwai@suse.de
- updated to version 1.0.14rc4
  * emu micro_dock firmware
* Sun Mar 18 2007 aj@suse.de
- /lib/firmware is now in filesystem package.
* Wed Mar 14 2007 tiwai@suse.de
- updated to version 1.0.14rc3:
  * updated asihpi firmwares
  * added msnd-pinnacle firmwares
  * fix usx2yaudio udev rules to call with proper -m option
* Wed Dec 20 2006 tiwai@suse.de
- updated to version 1.0.14rc1:
  * added ymfpci, maestro3, korg1212 firmwares
  * added wavefront and sb16 firmwares
  * added emi26/emi62 firmwares
* Thu Oct  5 2006 tiwai@suse.de
- updated to version 1.0.13-final:
  * no real change since rc2
* Fri Sep 22 2006 tiwai@suse.de
- updated to version 1.0.13rc2:
  * echoaduio firmware fixes
* Wed Aug 16 2006 tiwai@suse.de
- moved firmware-specific udev rules for usx2yaudio from alsa
  package.
* Tue Jul  4 2006 tiwai@suse.de
- updated to version 1.0.12rc1:
  * new firmwares for asihpi driver
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Oct 12 2005 tiwai@suse.de
- updated to version 1.0.10rc2.
* Sat Aug 20 2005 schwab@suse.de
- Don't require hotplug.
* Thu Jun  2 2005 tiwai@suse.de
- updated to version 1.0.9-final.
* Tue May 24 2005 tiwai@suse.de
- updated to version 1.0.9rc4.
- enable loaders, use symlinks for identical files.
* Thu Jan 13 2005 tiwai@suse.de
- updated to version 1.0.8-final.
* Fri Jan  7 2005 tiwai@suse.de
- added alsa to neededforpackage for $(datadir)/alsa ownership.
* Wed Jan  5 2005 tiwai@suse.de
- split from alsa-tools: version 1.0.8rc2.
